=========================================
Welcome to iGEM WikiSync's Documentation!
=========================================

iGEM WikiSync is an elegant and simple way to upload iGEM Wikis.

.. start-badges

.. image:: https://img.shields.io/pypi/v/igem-wikisync?style=for-the-badge
    :target: https://https://pypi.org/project/igem-wikisync/
    :alt: PyPI

.. image:: https://img.shields.io/coveralls/github/igembitsgoa/igem-wikisync?logo=coveralls&style=for-the-badge
    :alt: Coverage Status
    :target: https://coveralls.io/r/igembitsgoa/igem-wikisync

.. image:: https://img.shields.io/pypi/l/igem-wikisync?style=for-the-badge
    :alt: License: MIT


.. end-badges

WikiSync eliminates the need to manually upload each file, replace each URL and copy paste your source code into a web form. Building and deployment can now be as simple as a ``git push``, thanks to `Travis <https://travis-ci.com>`_.

Please head over to the :ref:`overview` to read more about this project, or dive right in with the :ref:`usage-guide`. We've also created a step-by-step :ref:`tutorial` to get your wiki up and running quickly.

Installation
------------

    .. code-block:: bash
    
        pip install igem-wikisync

Collaboration
-------------
Using this software or submitting issues and pull requests can count towards a collaboration for our teams. Please give us a shoutout at `@igem_bits <https://www.instagram.com/igem_bits>`_ on Instagram if WikiSync has made your iGEM experience easier! For contibuting to this software or discussing further collaborations, please reach out to us at igembitsgoa@gmail.com.

========
Contents
========

.. toctree::
   :maxdepth: 2

   overview
   installation
   tutorial/index
   usage/index
   reference/index
   contributing
   authors
   changelog

.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`

